# coding:utf-8

import pandas as pd
from sqlalchemy import create_engine

def import_concept_sectors(file_path, db_url, table_name):
    """
    从CSV文件导入概念板块数据到数据库。

    Parameters:
    -----------
    file_path : str
        CSV文件的路径
    db_url : str
        数据库连接URL
    table_name : str, optional
        要导入的数据库表名，默认为'gp_gnbk'

    Returns:
    --------
    bool
        导入成功返回True，失败返回False
    """
    try:
        # 读取 CSV 文件
        df = pd.read_csv(file_path, dtype={'gp_code': str}, encoding='gbk')
        
        # 创建数据库连接
        engine = create_engine(db_url)

        # 将数据写入数据库表
        df.to_sql(table_name, con=engine, if_exists='replace', index=False)
        
        print(f"数据已成功导入数据库表 '{table_name}'")
        return True
        
    except Exception as e:
        print(f"导入数据时发生错误: {str(e)}")
        return False

if __name__ == "__main__":
    # 示例调用
    file_path = "C:/Users/xy/Desktop/temp/概念板块.csv"
    db_url = 'mysql+pymysql://root:Chlry#$.8@192.168.18.199:3306/db_gp_cj'
    import_concept_sectors(file_path, db_url, "gp_gnbk")