#!/usr/bin/env python
"""
测试脚本: 验证导入路径是否正常工作
"""

import sys
import os
import logging

# 设置日志
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)
logger = logging.getLogger(__name__)

# 显示当前工作目录和Python路径
logger.info(f"当前工作目录: {os.getcwd()}")
logger.info(f"Python路径: {sys.path}")

def test_imports():
    """测试导入各个模块"""
    success = True
    
    # 测试导入 chat_bot
    try:
        logger.info("尝试导入 chat_bot 模块...")
        from fundamentals_llm.chat_bot import ChatBot
        logger.info("成功导入 chat_bot 模块")
    except ImportError as e:
        logger.error(f"导入 chat_bot 模块失败: {str(e)}")
        success = False
        
        # 尝试替代路径
        try:
            from src.fundamentals_llm.chat_bot import ChatBot
            logger.info("成功从替代路径导入 chat_bot 模块")
            success = True
        except ImportError as e2:
            logger.error(f"从替代路径导入 chat_bot 模块失败: {str(e2)}")
    
    # 测试导入 chat_bot_with_offline
    try:
        logger.info("尝试导入 chat_bot_with_offline 模块...")
        from fundamentals_llm.chat_bot_with_offline import ChatBot
        logger.info("成功导入 chat_bot_with_offline 模块")
    except ImportError as e:
        logger.error(f"导入 chat_bot_with_offline 模块失败: {str(e)}")
        success = False
        
        # 尝试替代路径
        try:
            from src.fundamentals_llm.chat_bot_with_offline import ChatBot
            logger.info("成功从替代路径导入 chat_bot_with_offline 模块")
            success = True
        except ImportError as e2:
            logger.error(f"从替代路径导入 chat_bot_with_offline 模块失败: {str(e2)}")
    
    # 测试导入 fundamental_analysis
    try:
        logger.info("尝试导入 fundamental_analysis 模块...")
        from fundamentals_llm.fundamental_analysis import FundamentalAnalyzer
        logger.info("成功导入 fundamental_analysis 模块")
    except ImportError as e:
        logger.error(f"导入 fundamental_analysis 模块失败: {str(e)}")
        success = False
        
        # 尝试替代路径
        try:
            from src.fundamentals_llm.fundamental_analysis import FundamentalAnalyzer
            logger.info("成功从替代路径导入 fundamental_analysis 模块")
            success = True
        except ImportError as e2:
            logger.error(f"从替代路径导入 fundamental_analysis 模块失败: {str(e2)}")
    
    # 测试导入 pdf_generator
    try:
        logger.info("尝试导入 pdf_generator 模块...")
        from fundamentals_llm.pdf_generator import generate_investment_report
        logger.info("成功导入 pdf_generator 模块")
    except ImportError as e:
        logger.error(f"导入 pdf_generator 模块失败: {str(e)}")
        success = False
        
        # 尝试替代路径
        try:
            from src.fundamentals_llm.pdf_generator import generate_investment_report
            logger.info("成功从替代路径导入 pdf_generator 模块")
            success = True
        except ImportError as e2:
            logger.error(f"从替代路径导入 pdf_generator 模块失败: {str(e2)}")
    
    return success

if __name__ == "__main__":
    logger.info("开始测试导入...")
    if test_imports():
        logger.info("所有导入测试通过")
        sys.exit(0)
    else:
        logger.error("导入测试失败")
        sys.exit(1) 